CREATE SCHEMA IF NOT EXISTS `Proiect`;
USE `Proiect`;

CREATE TABLE IF NOT EXISTS `proiect`.`Login` (
  `id` INT NOT NULL,
  `username` VARCHAR(45) NOT NULL,
  `password` VARCHAR(45) NOT NULL,
  `email` VARCHAR(45) NOT NULL,
  `tip` VARCHAR(45) NOT NULL,
  PRIMARY KEY (`id`),
  UNIQUE INDEX `username_UNIQUE` (`username` ASC))
ENGINE = InnoDB;

CREATE TABLE IF NOT EXISTS `proiect`.`Cont_firma` (
  `idFirma` INT NOT NULL,
  `nume` VARCHAR(45) NOT NULL,
  `cod_fiscal` VARCHAR(45) NOT NULL,
  `adresa` TEXT(100) NOT NULL,
  PRIMARY KEY (`idFirma`))
ENGINE = InnoDB;

CREATE TABLE IF NOT EXISTS `proiect`.`Cont_user` (
  `nume` VARCHAR(45) NOT NULL,
  `prenume` VARCHAR(45) NOT NULL,
  `data_nasterii` DATE NOT NULL,
  `adresa_livrare` TEXT(100) NOT NULL,
  `alte_informatii` TEXT(100) NULL,
  `Login_id` INT NOT NULL,
  `Firma_id` INT NULL,
  PRIMARY KEY (`Login_id`),
    FOREIGN KEY (`Login_id`)
    REFERENCES `proiect`.`Login` (`id`),
    FOREIGN KEY (`Firma_id`)
    REFERENCES `proiect`.`Cont_firma` (`idFirma`))
ENGINE = InnoDB;

CREATE TABLE IF NOT EXISTS `proiect`.`Card` (
  `numar_card` VARCHAR(16) NOT NULL,
  `data_expirare` DATE NOT NULL,
  `banca` VARCHAR(45) NOT NULL,
  `nume_de_pe_card` VARCHAR(45) NOT NULL,
  `idCard` INT NOT NULL,
  `Cont_id` INT NOT NULL,
  PRIMARY KEY (`idCard`),
    FOREIGN KEY (`Cont_id`)
    REFERENCES `proiect`.`Cont_user` (`Login_id`))
ENGINE = InnoDB;

CREATE TABLE IF NOT EXISTS `proiect`.`Istoric_comenzi` (
  `valoare` INT NOT NULL,
  `cantitate` INT NOT NULL,
  `data` DATE NOT NULL,
  `nume_produs` VARCHAR(45) NOT NULL,
  `Produs_id` INT NOT NULL,
  `Cont_id` INT NOT NULL,
  `idComanda` INT NOT NULL AUTO_INCREMENT,
  PRIMARY KEY (`idComanda`),
    FOREIGN KEY (`Cont_id`)
    REFERENCES `proiect`.`Cont_user` (`Login_id`))
ENGINE = InnoDB;

CREATE TABLE IF NOT EXISTS `proiect`.`Producator` (
  `idProducator` INT NOT NULL,
  `nume` VARCHAR(45) NOT NULL,
  `tara_origine` VARCHAR(45) NOT NULL,
  PRIMARY KEY (`idProducator`))
ENGINE = InnoDB;

CREATE TABLE IF NOT EXISTS `proiect`.`Produs` (
  `idProdus` INT NOT NULL,
  `Producator_id` INT NOT NULL,
  `nume` VARCHAR(70) NOT NULL,
  `cantitate` INT NOT NULL,
  `pret` INT NOT NULL,
  `tip` VARCHAR(45) NOT NULL,
  PRIMARY KEY (`idProdus`),
  UNIQUE INDEX `nume_UNIQUE` (`nume` ASC),
    FOREIGN KEY (`Producator_id`)
    REFERENCES `proiect`.`Producator` (`idProducator`))
ENGINE = InnoDB;

CREATE TABLE IF NOT EXISTS `proiect`.`Placa_de_baza` (
  `socket` VARCHAR(45) NOT NULL,
  `chipset` VARCHAR(45) NOT NULL,
  `Produs_id` INT NOT NULL,
  PRIMARY KEY (`Produs_id`),
    FOREIGN KEY (`Produs_id`)
    REFERENCES `proiect`.`Produs` (`idProdus`))
ENGINE = InnoDB;

CREATE TABLE IF NOT EXISTS `proiect`.`Procesor` (
  `socket` VARCHAR(45) NOT NULL,
  `nr_nuclee` INT NOT NULL,
  `frecventa` INT NOT NULL,
  `Produs_id` INT NOT NULL,
  PRIMARY KEY (`Produs_id`),
    FOREIGN KEY (`Produs_id`)
    REFERENCES `proiect`.`Produs` (`idProdus`))
ENGINE = InnoDB;

CREATE TABLE IF NOT EXISTS `proiect`.`Placa_video` (
  `memorie` INT NOT NULL,
  `bus` INT NOT NULL,
  `Produs_id` INT NOT NULL,
  PRIMARY KEY (`Produs_id`),
    FOREIGN KEY (`Produs_id`)
    REFERENCES `proiect`.`Produs` (`idProdus`))
ENGINE = InnoDB;

CREATE TABLE IF NOT EXISTS `proiect`.`Sursa` (
  `putere` INT NOT NULL,
  `Produs_id` INT NOT NULL,
  PRIMARY KEY (`Produs_id`),
    FOREIGN KEY (`Produs_id`)
    REFERENCES `proiect`.`Produs` (`idProdus`))
ENGINE = InnoDB;

CREATE TABLE IF NOT EXISTS `proiect`.`RAM` (
  `size_memorie` INT NOT NULL,
  `frecventa` INT NOT NULL,
  `tip` VARCHAR(4) NOT NULL,
  `Produs_id` INT NOT NULL,
  PRIMARY KEY (`Produs_id`),
    FOREIGN KEY (`Produs_id`)
    REFERENCES `proiect`.`Produs` (`idProdus`))
ENGINE = InnoDB;

CREATE TABLE IF NOT EXISTS `proiect`.`Stocare_hard` (
  `rpm` INT NOT NULL,
  `size_memorie` INT NOT NULL,
  `Produs_id` INT NOT NULL,
  PRIMARY KEY (`Produs_id`),
    FOREIGN KEY (`Produs_id`)
    REFERENCES `proiect`.`Produs` (`idProdus`))
ENGINE = InnoDB;

CREATE TABLE IF NOT EXISTS `proiect`.`Stocare_solid` (
  `read_speed` INT NOT NULL,
  `write_speed` INT NOT NULL,
  `size_memorie` INT NOT NULL,
  `Produs_id` INT NOT NULL,
  PRIMARY KEY (`Produs_id`),
    FOREIGN KEY (`Produs_id`)
    REFERENCES `proiect`.`Produs` (`idProdus`))
ENGINE = InnoDB;

CREATE TABLE IF NOT EXISTS `proiect`.`Comanda` (
  `Produs_id` INT NOT NULL,
  `Cont_id` INT NOT NULL,
  `cantitate` INT NOT NULL,
  `valoare` INT NOT NULL,
  `idComanda` INT NOT NULL,
  PRIMARY KEY (`idComanda`),
    FOREIGN KEY (`Produs_id`)
    REFERENCES `proiect`.`Produs` (`idProdus`),
    FOREIGN KEY (`Cont_id`)
    REFERENCES `proiect`.`Cont_user` (`Login_id`))
ENGINE = InnoDB;

CREATE TABLE IF NOT EXISTS `proiect`.`Cont_admin` (
  `nume` VARCHAR(45) NOT NULL,
  `prenume` VARCHAR(45) NOT NULL,
  `alte_informatii` TEXT(100) NULL,
  `Login_id` INT NOT NULL,
  PRIMARY KEY (`Login_id`),
    FOREIGN KEY (`Login_id`)
    REFERENCES `proiect`.`Login` (`id`))
ENGINE = InnoDB;

CREATE INDEX idx_Produs
ON Produs (idProdus);

CREATE INDEX idx_Cont_user
ON Cont_user (Login_id);

CREATE INDEX idx_Login
ON Login (username,password);

SET SQL_SAFE_UPDATES = 0;

CREATE USER 'user_proiect'@'localhost' IDENTIFIED BY '';
GRANT ALL PRIVILEGES ON proiect.* TO 'user_proiect'@'localhost' WITH GRANT OPTION;